# Installation

If not yet done, install and enable Apache and php-fpm. On Fedora you use `dnf` 
instead of `yum`, the rest stays the same:

    $ sudo yum -y install php-fpm httpd
    $ sudo systemctl enable --now php-fpm
    $ sudo systemctl enable --now httpd

On CentOS 7 you may need some additional configuration for php-fpm, see 
[this](https://developers.redhat.com/blog/2017/10/25/php-configuration-tips/) 
Red Hat blog post, or my 
[post](https://www.tuxed.net/fkooman/blog/centos_apache_php_fpm.html).

Install php-saml-sp:

    $ sudo yum -y install php-saml-sp
    $ sudo systemctl restart httpd

Configure your web server to use a TLS certificate, how to do this is out of
scope here.

# Configuration

All configuration takes place in the `/etc/php-saml-sp` directory. You can 
modify `config.php` in that folder.

The default configuration template contains instructions on how to modify the
file.

## Metadata

### Static 

You can place metadata for the IdPs that have access to your SP in 
`/etc/php-saml-sp/metadata`. Create the folder if it does not yet exist. You
can optionally restrict which IdPs have access to your SP by configuring 
`idpList` in `/etc/php-saml-sp/config.php`. By default all IdPs declared in
the metadata are allowed.

### Dynamic

You can automatically fetch SAML metadata and refresh it when required. You 
can configure the URLs in `/etc/php-saml-sp/config.php` under 
`metadataList`. The key is the URL, the value is an array of public keys that 
will be used to verify the metadata before accepting it.

The referenced key(s) MUST be placed in `/etc/php-saml-sp/metadata/keys`.

A `systemd` timer is available to run the metadata update every hour. It will 
use the `validUntil` field in the metadata (if it exists) to determine whether 
it is time to download new metadata.

To enable the timer:

    $ sudo systemctl enable --now php-saml-sp.timer

To trigger the immediate fetching of metadata, for example after changing the 
configuration:

    $ sudo systemctl start php-saml-sp

If all goes well, the metadata will be placed under 
`/var/lib/php-saml-sp/metadata`. You can check the journal to see the output
of the timer service:

    $ journalctl -t php-saml-sp-update-metadata

## Example
    
### Static

    # mkdir /etc/php-saml-sp/metadata
    # cd /etc/php-saml-sp/metadata
    # curl -o x509idp.moonshot.utr.surfcloud.nl.xml https://x509idp.moonshot.utr.surfcloud.nl/metadata

Verify the configuration file for syntax errors:

    # php -l /etc/php-saml-sp/config.php

If all is fine you should now be able to test your SP by going to 
`https://sp.example.org/php-saml-sp`, where `sp.example.org` is the host name 
of your server and click the "Test" button to start the SAML login.

### Dynamic

Modify `/etc/php-saml-sp/config.php`:

    'metadataList' => [
        'https://metadata.test.surfconext.nl/idp-metadata.xml' => ['SURFconext-metadata-signer.pem'],
        'https://metadata.wayf.dk/wayf-metadata.xml' => ['wayf.dk.crt'],
    ],

Make sure the configuration file is still syntactically valid:

     # php -l /etc/php-saml-sp/config.php

The certificates for the example entries can be found 
[here](https://metadata.surfconext.nl/SURFconext-metadata-signer.pem) and 
[here](https://wayf.dk/en/node/32) respectively. Put those in 
`/etc/php-saml-sp/metadata/keys`.

Run the timer script:

    $ sudo systemctl start php-saml-sp
